@@ -31,10 +31,14 @@ class Insider:
         return self.dns.sync()
 
     def add_service(self, name, protocol, type, port, url):
-        return self.dns.add_service(name, protocol, type, port, url)
+        result = self.dns.add_service(name, protocol, type, port, url)
+        self.sync_all()
+        return result
 
     def remove_service(self, name):
-        return self.dns.remove_service(name)
+        result = self.dns.remove_service(name)
+        self.sync_all()
+        return result
 
     def get_service(self, name):
         return self.dns.get_service(name)
@@ -47,12 +51,14 @@ class Insider:
 
     def acquire_domain(self, email, password, user_domain):
         result = self.dns.acquire(email, password, user_domain)
+        self.sync_all()
         self.cron.on()
         return result
 
     def drop_domain(self):
         self.dns.drop()
         self.cron.off()
+        self.sync_all()
 
     def full_name(self):
         return self.dns.full_name()
